@@ -25,11 +25,11 @@ class BaseHttpRequest:
     def get(
         self,
         path,
-        params=None,
-        headers=None,
+        params={},
+        headers={},
     ):
         url = self._get_url(path)
-        headers = self._get_headers()
+        headers = self._get_headers(headers)
         auth = self._get_auth()
         params = self._get_params(params)
 
@@ -60,11 +60,11 @@ class BaseHttpRequest:
         self,
         path,
         data,
-        params=None,
-        headers=None,
+        params={},
+        headers={},
     ):
         url = self._get_url(path)
-        headers = self._get_headers()
+        headers = self._get_headers(headers)
         auth = self._get_auth()
         params = self._get_params(params)
 
@@ -124,10 +124,15 @@ class BaseHttpRequest:
 
         headers["X-Requested-With"] = "XMLHttpRequest"
 
+        headers.update(self.host.headers)
+
         return headers
 
     def _get_params(self, params={}) -> Dict[str, str]:
-        return deepcopy(params)
+        params = deepcopy(params)
+        params.update(self.host.params)
+
+        return params
 
     def _get_url(self, path="") -> str:
         return f"{self.host.baseUrl}/{path}"
