@@ -12,15 +12,16 @@ log = logging.getLogger(__name__)
 
 @click.group("generate")
 def cli_generator():
+    """ Various commands for generating data/schemas """
     pass
 
 
 @cli_generator.command("json_schemas")
-@click.argument("id")
+@click.argument("host-id")
 @click.pass_obj
-def cmd_json_schemas(ctx, id: str):
+def cmd_json_schemas(ctx, host_id: str):
     """ Generate JSON Schemas from a dhis2 instance """
-    host = resolve_one(id, ctx.inventory)
+    host = resolve_one(host_id, ctx.inventory)
     schemas = load_and_parse_schema(host)
 
     if schemas:
